package cn.com.infosec.asn1.x509;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1InputStream;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.ASN1TaggedObject;
import cn.com.infosec.asn1.DERBitString;
import cn.com.infosec.asn1.DEREncodable;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERSequence;
import java.util.Enumeration;

public class SubjectPublicKeyInfo extends ASN1Encodable {
   private AlgorithmIdentifier algId;
   private DERBitString keyData;

   public static SubjectPublicKeyInfo getInstance(ASN1TaggedObject obj, boolean explicit) {
      return getInstance(ASN1Sequence.getInstance(obj, explicit));
   }

   public static SubjectPublicKeyInfo getInstance(Object obj) {
      if (obj instanceof SubjectPublicKeyInfo) {
         return (SubjectPublicKeyInfo)obj;
      } else if (obj instanceof ASN1Sequence) {
         return new SubjectPublicKeyInfo((ASN1Sequence)obj);
      } else {
         throw new IllegalArgumentException("unknown object in factory: " + obj.getClass().getName());
      }
   }

   public SubjectPublicKeyInfo(AlgorithmIdentifier algId, DEREncodable publicKey) {
      SubjectPublicKeyInfo var10000 = this;
      SubjectPublicKeyInfo var10001 = this;
      super();
      DERBitString var3;
      var3 = new DERBitString.<init>(publicKey);
      var10001.keyData = var3;
      var10000.algId = algId;
   }

   public SubjectPublicKeyInfo(AlgorithmIdentifier algId, byte[] publicKey) {
      SubjectPublicKeyInfo var10000 = this;
      SubjectPublicKeyInfo var10001 = this;
      super();
      DERBitString var3;
      var3 = new DERBitString.<init>(publicKey);
      var10001.keyData = var3;
      var10000.algId = algId;
   }

   public SubjectPublicKeyInfo(ASN1Sequence seq) {
      if (seq.size() == 2) {
         SubjectPublicKeyInfo var10000 = this;
         Enumeration var2;
         this.algId = AlgorithmIdentifier.getInstance((var2 = seq.getObjects()).nextElement());
         var10000.keyData = DERBitString.getInstance(var2.nextElement());
      } else {
         throw new IllegalArgumentException("Bad sequence size: " + seq.size());
      }
   }

   public AlgorithmIdentifier getAlgorithmId() {
      return this.algId;
   }

   public DERObject getPublicKey() {
      return (new ASN1InputStream(this.keyData.getBytes())).readObject();
   }

   public DERBitString getPublicKeyData() {
      return this.keyData;
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      ASN1EncodableVector var10000 = var1 = new ASN1EncodableVector;
      var1.<init>();
      var1.add(this.algId);
      var10000.add(this.keyData);
      return new DERSequence(var1);
   }
}
